@@ -5,7 +5,7 @@ def main():
              © 2025 MiraNova Studios
 
         Lyric is coming soon.
-        Visit https://miranova.studio/lyric.html
+        Visit http://miranova.studio/lyric.html
     ────────────────────────────────────────────────
     """
     print(banner.strip())
